"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.formatUrlPath = exports.getWithContentTypeCsv = exports.acceptCsvFiletype = exports.getOptions = exports.addSearchQuery = exports.makePath = exports.isEmpty = exports.getFn = void 0;

var _axios = _interopRequireDefault(require("axios"));

var _jsFileDownload = _interopRequireDefault(require("js-file-download"));

var _lodash = require("lodash");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const isNotForwardSlash = v => v && v !== '/';

const prependForwardSlash = v => {
  let output = String(v);
  if (output.startsWith('/')) output = output.substr(1);
  if (output.charAt(output.length - 1) === '/') output = output.substring(0, output.length - 1);
  return `/${output}`;
};

const getFn = (obj, prop) => {
  if (!(prop in obj) || typeof obj[prop] !== 'function') throw new Error('Unknown action');
  return obj[prop]();
};

exports.getFn = getFn;

const isEmpty = obj => !obj || typeof obj === 'object' && !Object.keys(obj).length && !(obj instanceof Error);

exports.isEmpty = isEmpty;

const makePath = (a = []) => a.filter(isNotForwardSlash).map(prependForwardSlash).join('');

exports.makePath = makePath;

const extractData = (v, path) => {
  const data = (0, _lodash.get)(v, path);
  return data ? {
    label: data,
    value: v.id,
    ...v
  } : {
    label: data,
    value: data
  };
};

const addSearchQuery = (v, term) => v.includes('?') ? `${v}&search=${term}` : `${v}?search=${term}`;

exports.addSearchQuery = addSearchQuery;

const getOptions = (url, key, pathToLabel, flatten = false) => _axios.default.get(url).then(({
  data
}) => pathToLabel ? (0, _lodash.get)(data, key, []).map(i => flatten ? (0, _lodash.get)(i, pathToLabel) : extractData(i, pathToLabel)) : (0, _lodash.get)(data, key, [])).catch(() => {
  return [];
});

exports.getOptions = getOptions;

const acceptCsvFiletype = (params = {}) => (data, headers) => {
  Object.assign(headers, params, {
    'Accept': 'text/csv'
  });
  return data;
};

exports.acceptCsvFiletype = acceptCsvFiletype;

const getWithContentTypeCsv = (url, params) => (0, _axios.default)({
  url,
  method: 'get',
  transformRequest: [acceptCsvFiletype(params)]
});

exports.getWithContentTypeCsv = getWithContentTypeCsv;

const formatUrlPath = (url, query, select) => {
  let endpoint = url;

  const hasQuery = v => v.includes('?');

  const appendAmpersand = v => v.startsWith('&') ? v : `&${v}`;

  const hasLength = v => typeof v === 'string' && v.length;

  const addToEndpoint = v => {
    if (hasQuery(endpoint)) {
      endpoint += appendAmpersand(v.replace('?', '&'));
    } else if (v.startsWith('&')) {
      endpoint += endpoint.endsWith('&') ? v.substr(1) : v;
    } else {
      endpoint += !v.startsWith('?') ? `?${v}` : v;
    }
  };

  if (hasLength(query)) addToEndpoint(query);
  if (hasLength(select)) addToEndpoint(`&fields=${select}`);
  return endpoint;
};

exports.formatUrlPath = formatUrlPath;